# Python Package Demo

This is an example package for the Nanodegree for Data Science at Udacity to help understand how to create and distribute a python package. For this package, I created a simple guessing game with a Quantum Physics Theme to 
make the game more enjoyable. 

# Contents
The package QuantumGame will include the following files in the directory:
- init.py file 
- main.py file (used to run the game)
- QuantumGuessGame.py  file
- QuantumUniverse.py file
- setup.py file 
- license.txt


# How to install and use package
Once you have successfully downloaded your package. You simply may run the main.py program from terminal to start the game. The game will load and will ask the user for inputs for the guessing game and you will be give a score once the game is complete. 